==> libopenmpt-0.4.53-pre.0+r24695.doc.tar.gz: libopenmpt-0.4.53-pre.0+r24695.doc/docs/group__libopenmpt__cpp.js <==
var group__libopenmpt__cpp =
[
    [ "string", "namespaceopenmpt_1_1string.html", null ],
    [ "exception", "classopenmpt_1_1exception.html", [
      [ "exception", "classopenmpt_1_1exception.html#aee4e972c2304c567fedd39157bc687e8", null ],
      [ "exception", "classopenmpt_1_1exception.html#af9cd2a6ead1462f4d7ba7d205fc071b6", null ],
      [ "exception", "classopenmpt_1_1exception.html#a2d9cf98929191df23ef6a439f01d42d8", null ],
      [ "~exception", "classopenmpt_1_1exception.html#afa52de10aaf7bc9b234fbd1849fd68e0", null ],
      [ "what", "classopenmpt_1_1exception.html#a8f50dfe01e33bfa845cffafdb0406e9c", null ]
    ] ],
    [ "module", "classopenmpt_1_1module.html", [
      [ "command_index", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0", [
        [ "command_note", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0aaf05a706b8ee4214f493155033b5a0d4", null ],
        [ "command_instrument", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0a4e9e6670d6d2a756ec787c586778913a", null ],
        [ "command_volumeffect", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0adef5a73b7aca8323235b0c553eae997d", null ],
        [ "command_effect", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0a681daaf0ed1cdc06c617e2b1d2477ab1", null ],
        [ "command_volume", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0afcb70f73f95999944c4fde43f3924711", null ],
        [ "command_parameter", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0a40c1f5dabbb9fb0a5f4c741613006998", null ]
      ] ],
      [ "render_param", "classopenmpt_1_1module.html#ab4ae2823cb180657142f5f1a93cd64aa", [
        [ "RENDER_MASTERGAIN_MILLIBEL", "classopenmpt_1_1module.html#ab4ae2823cb180657142f5f1a93cd64aaa759a6d01d0fcfd881bbb87cdd42cfad0", null ],
        [ "RENDER_STEREOSEPARATION_PERCENT", "classopenmpt_1_1module.html#ab4ae2823cb180657142f5f1a93cd64aaa09035a1e6ab1dbc04f574acc18fdcfbc", null ],
        [ "RENDER_INTERPOLATIONFILTER_LENGTH", "classopenmpt_1_1module.html#ab4ae2823cb180657142f5f1a93cd64aaa876090d11a72655ee4087b3f1abf1476", null ],
        [ "RENDER_VOLUMERAMPING_STRENGTH", "classopenmpt_1_1module.html#ab4ae2823cb180657142f5f1a93cd64aaa8e1204b27be1f116b5dd48891649b8a0", null ]
      ] ],
      [ "module", "classopenmpt_1_1module.html#a8c2027028a9dab94f42e52feab8a5e27", null ],
      [ "module", "classopenmpt_1_1module.html#ad63f24715a626a15787daa304b318e3c", null ],
      [ "module", "classopenmpt_1_1module.html#a1d5a1aa570a52aed4c9c401b2aa52a9e", null ],
      [ "module", "classopenmpt_1_1module.html#ad7ba0feb5197b93860ef307ebf262d44", null ],
      [ "module", "classopenmpt_1_1module.html#a5f4af363cc36b2bf992ef56a9aef4ea8", null ],
      [ "module", "classopenmpt_1_1module.html#a35aead5cc54f44b08c70db86d658af13", null ],
      [ "module", "classopenmpt_1_1module.html#ab681cbdd89e96a52c91aa7a8573319aa", null ],
      [ "module", "classopenmpt_1_1module.html#a9d3c93dc045cf8db1e12328f40e78509", null ],
      [ "~module", "classopenmpt_1_1module.html#a2255bfcaef1faad280fa9b6f5162d161", null ],
      [ "ctl_get", "classopenmpt_1_1module.html#a80573da2614c3763da739e8245009a78", null ],
      [ "ctl_set", "classopenmpt_1_1module.html#a8a65a2fdb18ad33447fd12c824b95bb7", null ],
      [ "format_pattern_row_channel", "classopenmpt_1_1module.html#a04cc6730c3e46a79bf5d4806264e1442", null ],
      [ "format_pattern_row_channel_command", "classopenmpt_1_1module.html#a12ff1a0abaec337670a87cc561e6ce4a", null ],
      [ "get_channel_names", "classopenmpt_1_1module.html#af88d77bca37e22e09f790105fe7a3be8", null ],
      [ "get_ctls", "classopenmpt_1_1module.html#aef49052263ab2e28428b31feba2e88eb", null ],
      [ "get_current_channel_vu_left", "classopenmpt_1_1module.html#a81c47af4016aef177c3d99373a6a45ad", null ],
      [ "get_current_channel_vu_mono", "classopenmpt_1_1module.html#a6f0c4bb9c1deeb8c416dc3aae4d8030d", null ],
      [ "get_current_channel_vu_rear_left", "classopenmpt_1_1module.html#a33af61124dc274cb429527b4da67d08e", null ],
      [ "get_current_channel_vu_rear_right", "classopenmpt_1_1module.html#a624b707629f8f89b5a2d8801fee045cc", null ],
      [ "get_current_channel_vu_right", "classopenmpt_1_1module.html#a7791c59c84c5a3e487e8f76ab36c2116", null ],
      [ "get_current_order", "classopenmpt_1_1module.html#a6bdeac1eebcad5f3daaf6bffbb010c44", null ],
      [ "get_current_pattern", "classopenmpt_1_1module.html#a7c444d38be4c06d4ec3b988fd0caf65e", null ],
      [ "get_current_playing_channels", "classopenmpt_1_1module.html#a6a8026428cfc72c6ac7b674bb4da5302", null ],
      [ "get_current_row", "classopenmpt_1_1module.html#a03e930a5a44cdb8e987dac7d214b57e2", null ],
      [ "get_current_speed", "classopenmpt_1_1module.html#a312cab145cd7347dfc611cb36a34551d", null ],
      [ "get_current_tempo", "classopenmpt_1_1module.html#ad7c57950f5e7f9fa8e42c162fe7c2735", null ],
      [ "get_duration_seconds", "classopenmpt_1_1module.html#ad06c7d9c244f71543792c2877d3a4d9e", null ],
      [ "get_instrument_names", "classopenmpt_1_1module.html#aeef9524c73819860086485342068b9e1", null ],
      [ "get_metadata", "classopenmpt_1_1module.html#af96796d3e7d698a63b7779f50050dd17", null ],
      [ "get_metadata_keys", "classopenmpt_1_1module.html#ae2cea366c3873d024a22f2862d3ca365", null ],
      [ "get_num_channels", "classopenmpt_1_1module.html#abc8052c5ed412d011e95e0f592697eb2", null ],
      [ "get_num_instruments", "classopenmpt_1_1module.html#aa5b8885ada0a068c524332720998b690", null ],
      [ "get_num_orders", "classopenmpt_1_1module.html#a4d45e4a6ff2a98094d325db144eec404", null ],
      [ "get_num_patterns", "classopenmpt_1_1module.html#aacee757c7f66b9e5a345a5330cc8351e", null ],
      [ "get_num_samples", "classopenmpt_1_1module.html#a4f2f9bc4e2046492d1183cef223b4401", null ],
      [ "get_num_subsongs", "classopenmpt_1_1module.html#a49005bd92a2f7e4f9e9cd2c0d57a815e", null ],
      [ "get_order_names", "classopenmpt_1_1module.html#a458817b67cb3db036cf85c47e87ac7c0", null ],
      [ "get_order_pattern", "classopenmpt_1_1module.html#a85d702026eedbc5735e508864c4e5abb", null ],
      [ "get_pattern_names", "classopenmpt_1_1module.html#a36cbc1d41f17cf035855bde3ffb6783c", null ],
      [ "get_pattern_num_rows", "classopenmpt_1_1module.html#a99206d383226c2d1bdb4b9eb5efcb52d", null ],
      [ "get_pattern_row_channel_command", "classopenmpt_1_1module.html#acd958bd722ab2e8979baf857e9784fba", null ],
      [ "get_position_seconds", "classopenmpt_1_1module.html#a05e92b4a21a65d2f2ec9d6e9102054a5", null ],
      [ "get_render_param", "classopenmpt_1_1module.html#aec664b518e72d79f73e0aa44411310c5", null ],
      [ "get_repeat_count", "classopenmpt_1_1module.html#a04f2db2b22ac12ee8a169128d0ec952e", null ],
      [ "get_sample_names", "classopenmpt_1_1module.html#adaacb1440b2ab224702ee437f7c84a1d", null ],
      [ "get_selected_subsong", "classopenmpt_1_1module.html#a908198092b6d8da143da225584d725ae", null ],
      [ "get_subsong_names", "classopenmpt_1_1module.html#a01fd0f9cb938b6bb6ded6b01f4305a75", null ],
      [ "highlight_pattern_row_channel", "classopenmpt_1_1module.html#afd6430b4062b970456779eaca81159b8", null ],
      [ "highlight_pattern_row_channel_command", "classopenmpt_1_1module.html#a2f972d8720ac1a172922f1d64278d880", null ],
      [ "read", "classopenmpt_1_1module.html#a2cd8b1002a714f6d3fecfaa2cde7fcc0", null ],
      [ "read", "classopenmpt_1_1module.html#a212663640cc22b394ef9f1f20d7d77af", null ],
      [ "read", "classopenmpt_1_1module.html#a2623592ce920efb959a21838a7b9dfe1", null ],
      [ "read", "classopenmpt_1_1module.html#a956e3e40902c9e5c6e3b51159390bacf", null ],
      [ "read", "classopenmpt_1_1module.html#aca43e7a7ccfead79a268aaeb04c1bbdd", null ],
      [ "read", "classopenmpt_1_1module.html#a6688c053dbcd0cf58d996e97ce17a5a8", null ],
      [ "read_interleaved_quad", "classopenmpt_1_1module.html#abf0c1928580178f45d28116afa17c78a", null ],
      [ "read_interleaved_quad", "classopenmpt_1_1module.html#a3e1f44f3ec8235fa3397f444707ed481", null ],
      [ "read_interleaved_stereo", "classopenmpt_1_1module.html#ad89f8f7bc39958c449a0fa630bb1bc69", null ],
      [ "read_interleaved_stereo", "classopenmpt_1_1module.html#a467fd3730c7f3b45d349436cb56c4842", null ],
      [ "select_subsong", "classopenmpt_1_1module.html#afd5c072b59fb871d7e63141093473189", null ],
      [ "set_position_order_row", "classopenmpt_1_1module.html#ae7673a35376b3560d242ad81f67d37bc", null ],
      [ "set_position_seconds", "classopenmpt_1_1module.html#a04d1248993aa3ecd00bf83a460c5e1e7", null ],
      [ "set_render_param", "classopenmpt_1_1module.html#aa968764ca575d484cc271deb6f610cf8", null ],
      [ "set_repeat_count", "classopenmpt_1_1module.html#a00a598350f93e0d4371093846d0bbbd8", null ],
      [ "module_ext", "classopenmpt_1_1module.html#a06bcba479a1ea6f5aa78a34838b128ca", null ]
    ] ],
    [ "probe_file_header_result", "group__libopenmpt__cpp.html#ga2bfab5a4d171e48c0de55806174552b1", [
      [ "probe_file_header_result_success", "group__libopenmpt__cpp.html#gga2bfab5a4d171e48c0de55806174552b1a30801347bba0cd61e700605a10d108b7", null ],
      [ "probe_file_header_result_failure", "group__libopenmpt__cpp.html#gga2bfab5a4d171e48c0de55806174552b1a31d073e7dc36b213618f635ec90f5d2b", null ],
      [ "probe_file_header_result_wantmoredata", "group__libopenmpt__cpp.html#gga2bfab5a4d171e48c0de55806174552b1acf3e6c33d72266e9c0d34da84fb7ec1f", null ]
    ] ],
    [ "could_open_probability", "group__libopenmpt__cpp.html#ga95fd9b6781cd291b48a1c3e12a3c85e1", null ],
    [ "could_open_propability", "group__libopenmpt__cpp.html#gaad5e4ff0e24869d7a9808ac4262283f2", null ],
    [ "get_core_version", "group__libopenmpt__cpp.html#gac37146367d4849a17a297d388cfb4811", null ],
    [ "get_library_version", "group__libopenmpt__cpp.html#gaeece2f6ce1045a5f519c93ce19e6eef3", null ],
    [ "get_supported_extensions", "group__libopenmpt__cpp.html#gaaa2081245974442462d76e8b9bc9380a", null ],
    [ "is_extension_supported", "group__libopenmpt__cpp.html#gaafc5dab5b9c0b8324bbedcc01b59a3c0", null ],
    [ "probe_file_header", "group__libopenmpt__cpp.html#gad77e7cf2361d664fda8ae8461c1dc7a0", null ],
    [ "probe_file_header", "group__libopenmpt__cpp.html#ga77facf516dd9b626847f91ac26047336", null ],
    [ "probe_file_header", "group__libopenmpt__cpp.html#ga6412e44030e40ca67aaa187691ad8e9c", null ],
    [ "probe_file_header_get_recommended_size", "group__libopenmpt__cpp.html#gaf70a8d33fdceca5a821755106e840dcb", null ],
    [ "probe_file_header_flags_containers", "group__libopenmpt__cpp.html#gad8b455af763397bc1b331ab5a0e47526", null ],
    [ "probe_file_header_flags_default", "group__libopenmpt__cpp.html#gae58576f977f7d74f12f37344223a0e78", null ],
    [ "probe_file_header_flags_modules", "group__libopenmpt__cpp.html#ga92c11980bfec1deb5f5d4f8fa6e4e998", null ],
    [ "probe_file_header_flags_none", "group__libopenmpt__cpp.html#ga631d4fb8e89a9f5f995827b07812c736", null ]
];

==> libopenmpt-0.6.27-pre.0+r24640.doc.tar.gz: libopenmpt-0.6.27-pre.0+r24640.doc/docs/group__libopenmpt__cpp.js <==
var group__libopenmpt__cpp =
[
    [ "exception", "classopenmpt_1_1exception.html", [
      [ "exception", "classopenmpt_1_1exception.html#aee4e972c2304c567fedd39157bc687e8", null ],
      [ "exception", "classopenmpt_1_1exception.html#af9cd2a6ead1462f4d7ba7d205fc071b6", null ],
      [ "exception", "classopenmpt_1_1exception.html#a2d9cf98929191df23ef6a439f01d42d8", null ],
      [ "~exception", "classopenmpt_1_1exception.html#afa52de10aaf7bc9b234fbd1849fd68e0", null ],
      [ "what", "classopenmpt_1_1exception.html#a8f50dfe01e33bfa845cffafdb0406e9c", null ]
    ] ],
    [ "module", "classopenmpt_1_1module.html", [
      [ "command_index", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0", [
        [ "command_note", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0aaf05a706b8ee4214f493155033b5a0d4", null ],
        [ "command_instrument", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0a4e9e6670d6d2a756ec787c586778913a", null ],
        [ "command_volumeffect", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0adef5a73b7aca8323235b0c553eae997d", null ],
        [ "command_effect", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0a681daaf0ed1cdc06c617e2b1d2477ab1", null ],
        [ "command_volume", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0afcb70f73f95999944c4fde43f3924711", null ],
        [ "command_parameter", "classopenmpt_1_1module.html#ac365dda43e6aeed009f3950392d537d0a40c1f5dabbb9fb0a5f4c741613006998", null ]
      ] ],
      [ "render_param", "classopenmpt_1_1module.html#ab4ae2823cb180657142f5f1a93cd64aa", [
        [ "RENDER_MASTERGAIN_MILLIBEL", "classopenmpt_1_1module.html#ab4ae2823cb180657142f5f1a93cd64aaa759a6d01d0fcfd881bbb87cdd42cfad0", null ],
        [ "RENDER_STEREOSEPARATION_PERCENT", "classopenmpt_1_1module.html#ab4ae2823cb180657142f5f1a93cd64aaa09035a1e6ab1dbc04f574acc18fdcfbc", null ],
        [ "RENDER_INTERPOLATIONFILTER_LENGTH", "classopenmpt_1_1module.html#ab4ae2823cb180657142f5f1a93cd64aaa876090d11a72655ee4087b3f1abf1476", null ],
        [ "RENDER_VOLUMERAMPING_STRENGTH", "classopenmpt_1_1module.html#ab4ae2823cb180657142f5f1a93cd64aaa8e1204b27be1f116b5dd48891649b8a0", null ]
      ] ],
      [ "module", "classopenmpt_1_1module.html#a8c2027028a9dab94f42e52feab8a5e27", null ],
      [ "module", "classopenmpt_1_1module.html#a199dc152b432ca37118f65fe74cea102", null ],
      [ "module", "classopenmpt_1_1module.html#af101e76f50124e6267e1797a67c3b488", null ],
      [ "module", "classopenmpt_1_1module.html#a3953dd802772c7a43e4a79ebf7de5e32", null ],
      [ "module", "classopenmpt_1_1module.html#ad63f24715a626a15787daa304b318e3c", null ],
      [ "module", "classopenmpt_1_1module.html#a1d5a1aa570a52aed4c9c401b2aa52a9e", null ],
      [ "module", "classopenmpt_1_1module.html#ad7ba0feb5197b93860ef307ebf262d44", null ],
      [ "module", "classopenmpt_1_1module.html#a5f4af363cc36b2bf992ef56a9aef4ea8", null ],
      [ "module", "classopenmpt_1_1module.html#a35aead5cc54f44b08c70db86d658af13", null ],
      [ "module", "classopenmpt_1_1module.html#ab681cbdd89e96a52c91aa7a8573319aa", null ],
      [ "module", "classopenmpt_1_1module.html#a9d3c93dc045cf8db1e12328f40e78509", null ],
      [ "~module", "classopenmpt_1_1module.html#a2255bfcaef1faad280fa9b6f5162d161", null ],
      [ "ctl_get", "classopenmpt_1_1module.html#ab2695af0baa274054f5687741fa7c05b", null ],
      [ "ctl_get_boolean", "classopenmpt_1_1module.html#aded24d860ccca2f1206e22438f39e222", null ],
      [ "ctl_get_floatingpoint", "classopenmpt_1_1module.html#ab9d0aa0a548f461f454b54950e224fa9", null ],
      [ "ctl_get_integer", "classopenmpt_1_1module.html#afe068d192459460663a584ae34bd1016", null ],
      [ "ctl_get_text", "classopenmpt_1_1module.html#ad72706fff3c9c898acce3c2670f57eca", null ],
      [ "ctl_set", "classopenmpt_1_1module.html#afaa59b7382a7639b6394b535f5f0c7ac", null ],
      [ "ctl_set_boolean", "classopenmpt_1_1module.html#ac7e5f7acefe6fb12e73d78883f4c452e", null ],
      [ "ctl_set_floatingpoint", "classopenmpt_1_1module.html#a162deabc53123ca38c3f88f6e4cb296d", null ],
      [ "ctl_set_integer", "classopenmpt_1_1module.html#a4512c2bd08da291242a4ba6edb8c67c2", null ],
      [ "ctl_set_text", "classopenmpt_1_1module.html#afa338b7fc1b5c23ff0381f5a9ddc77f4", null ],
      [ "format_pattern_row_channel", "classopenmpt_1_1module.html#a04cc6730c3e46a79bf5d4806264e1442", null ],
      [ "format_pattern_row_channel_command", "classopenmpt_1_1module.html#a12ff1a0abaec337670a87cc561e6ce4a", null ],
      [ "get_channel_names", "classopenmpt_1_1module.html#af88d77bca37e22e09f790105fe7a3be8", null ],
      [ "get_ctls", "classopenmpt_1_1module.html#aef49052263ab2e28428b31feba2e88eb", null ],
      [ "get_current_channel_vu_left", "classopenmpt_1_1module.html#a81c47af4016aef177c3d99373a6a45ad", null ],
      [ "get_current_channel_vu_mono", "classopenmpt_1_1module.html#a6f0c4bb9c1deeb8c416dc3aae4d8030d", null ],
      [ "get_current_channel_vu_rear_left", "classopenmpt_1_1module.html#a33af61124dc274cb429527b4da67d08e", null ],
      [ "get_current_channel_vu_rear_right", "classopenmpt_1_1module.html#a624b707629f8f89b5a2d8801fee045cc", null ],
      [ "get_current_channel_vu_right", "classopenmpt_1_1module.html#a7791c59c84c5a3e487e8f76ab36c2116", null ],
      [ "get_current_estimated_bpm", "classopenmpt_1_1module.html#a49cbe82a8b3fd631fbfbc5fecd69fd36", null ],
      [ "get_current_order", "classopenmpt_1_1module.html#a6bdeac1eebcad5f3daaf6bffbb010c44", null ],
      [ "get_current_pattern", "classopenmpt_1_1module.html#a7c444d38be4c06d4ec3b988fd0caf65e", null ],
      [ "get_current_playing_channels", "classopenmpt_1_1module.html#a6a8026428cfc72c6ac7b674bb4da5302", null ],
      [ "get_current_row", "classopenmpt_1_1module.html#a03e930a5a44cdb8e987dac7d214b57e2", null ],
      [ "get_current_speed", "classopenmpt_1_1module.html#a312cab145cd7347dfc611cb36a34551d", null ],
      [ "get_current_tempo", "classopenmpt_1_1module.html#ad7c57950f5e7f9fa8e42c162fe7c2735", null ],
      [ "get_duration_seconds", "classopenmpt_1_1module.html#ad06c7d9c244f71543792c2877d3a4d9e", null ],
      [ "get_instrument_names", "classopenmpt_1_1module.html#aeef9524c73819860086485342068b9e1", null ],
      [ "get_metadata", "classopenmpt_1_1module.html#af96796d3e7d698a63b7779f50050dd17", null ],
      [ "get_metadata_keys", "classopenmpt_1_1module.html#ae2cea366c3873d024a22f2862d3ca365", null ],
      [ "get_num_channels", "classopenmpt_1_1module.html#abc8052c5ed412d011e95e0f592697eb2", null ],
      [ "get_num_instruments", "classopenmpt_1_1module.html#aa5b8885ada0a068c524332720998b690", null ],
      [ "get_num_orders", "classopenmpt_1_1module.html#a4d45e4a6ff2a98094d325db144eec404", null ],
      [ "get_num_patterns", "classopenmpt_1_1module.html#aacee757c7f66b9e5a345a5330cc8351e", null ],
      [ "get_num_samples", "classopenmpt_1_1module.html#a4f2f9bc4e2046492d1183cef223b4401", null ],
      [ "get_num_subsongs", "classopenmpt_1_1module.html#a49005bd92a2f7e4f9e9cd2c0d57a815e", null ],
      [ "get_order_names", "classopenmpt_1_1module.html#a458817b67cb3db036cf85c47e87ac7c0", null ],
      [ "get_order_pattern", "classopenmpt_1_1module.html#a85d702026eedbc5735e508864c4e5abb", null ],
      [ "get_pattern_names", "classopenmpt_1_1module.html#a36cbc1d41f17cf035855bde3ffb6783c", null ],
      [ "get_pattern_num_rows", "classopenmpt_1_1module.html#a99206d383226c2d1bdb4b9eb5efcb52d", null ],
      [ "get_pattern_row_channel_command", "classopenmpt_1_1module.html#acd958bd722ab2e8979baf857e9784fba", null ],
      [ "get_position_seconds", "classopenmpt_1_1module.html#a05e92b4a21a65d2f2ec9d6e9102054a5", null ],
      [ "get_render_param", "classopenmpt_1_1module.html#aec664b518e72d79f73e0aa44411310c5", null ],
      [ "get_repeat_count", "classopenmpt_1_1module.html#a04f2db2b22ac12ee8a169128d0ec952e", null ],
      [ "get_sample_names", "classopenmpt_1_1module.html#adaacb1440b2ab224702ee437f7c84a1d", null ],
      [ "get_selected_subsong", "classopenmpt_1_1module.html#a908198092b6d8da143da225584d725ae", null ],
      [ "get_subsong_names", "classopenmpt_1_1module.html#a01fd0f9cb938b6bb6ded6b01f4305a75", null ],
      [ "highlight_pattern_row_channel", "classopenmpt_1_1module.html#afd6430b4062b970456779eaca81159b8", null ],
      [ "highlight_pattern_row_channel_command", "classopenmpt_1_1module.html#a2f972d8720ac1a172922f1d64278d880", null ],
      [ "read", "classopenmpt_1_1module.html#aca43e7a7ccfead79a268aaeb04c1bbdd", null ],
      [ "read", "classopenmpt_1_1module.html#a6688c053dbcd0cf58d996e97ce17a5a8", null ],
      [ "read", "classopenmpt_1_1module.html#a956e3e40902c9e5c6e3b51159390bacf", null ],
      [ "read", "classopenmpt_1_1module.html#a212663640cc22b394ef9f1f20d7d77af", null ],
      [ "read", "classopenmpt_1_1module.html#a2623592ce920efb959a21838a7b9dfe1", null ],
      [ "read", "classopenmpt_1_1module.html#a2cd8b1002a714f6d3fecfaa2cde7fcc0", null ],
      [ "read_interleaved_quad", "classopenmpt_1_1module.html#a3e1f44f3ec8235fa3397f444707ed481", null ],
      [ "read_interleaved_quad", "classopenmpt_1_1module.html#abf0c1928580178f45d28116afa17c78a", null ],
      [ "read_interleaved_stereo", "classopenmpt_1_1module.html#a467fd3730c7f3b45d349436cb56c4842", null ],
      [ "read_interleaved_stereo", "classopenmpt_1_1module.html#ad89f8f7bc39958c449a0fa630bb1bc69", null ],
      [ "select_subsong", "classopenmpt_1_1module.html#afd5c072b59fb871d7e63141093473189", null ],
      [ "set_position_order_row", "classopenmpt_1_1module.html#ae7673a35376b3560d242ad81f67d37bc", null ],
      [ "set_position_seconds", "classopenmpt_1_1module.html#a04d1248993aa3ecd00bf83a460c5e1e7", null ],
      [ "set_render_param", "classopenmpt_1_1module.html#aa968764ca575d484cc271deb6f610cf8", null ],
      [ "set_repeat_count", "classopenmpt_1_1module.html#a00a598350f93e0d4371093846d0bbbd8", null ],
      [ "module_ext", "classopenmpt_1_1module.html#a06bcba479a1ea6f5aa78a34838b128ca", null ]
    ] ],
    [ "probe_file_header_flags", "group__libopenmpt__cpp.html#ga1d723b4fa39dd65db926736f04cea77e", [
      [ "probe_file_header_flags_modules2", "group__libopenmpt__cpp.html#gga1d723b4fa39dd65db926736f04cea77eadd907cd3abbac2d828efb7146d4185d2", null ],
      [ "probe_file_header_flags_containers2", "group__libopenmpt__cpp.html#gga1d723b4fa39dd65db926736f04cea77eaabb810fe476bd08cd839f4899c580902", null ],
      [ "probe_file_header_flags_default2", "group__libopenmpt__cpp.html#gga1d723b4fa39dd65db926736f04cea77ea9429374c9cf2b759acef9fa8858f3e8e", null ],
      [ "probe_file_header_flags_none2", "group__libopenmpt__cpp.html#gga1d723b4fa39dd65db926736f04cea77ea6fa2dbd5c74702e96a3342ec010d1104", null ]
    ] ],
    [ "probe_file_header_result", "group__libopenmpt__cpp.html#ga2bfab5a4d171e48c0de55806174552b1", [
      [ "probe_file_header_result_success", "group__libopenmpt__cpp.html#gga2bfab5a4d171e48c0de55806174552b1a30801347bba0cd61e700605a10d108b7", null ],
      [ "probe_file_header_result_failure", "group__libopenmpt__cpp.html#gga2bfab5a4d171e48c0de55806174552b1a31d073e7dc36b213618f635ec90f5d2b", null ],
      [ "probe_file_header_result_wantmoredata", "group__libopenmpt__cpp.html#gga2bfab5a4d171e48c0de55806174552b1acf3e6c33d72266e9c0d34da84fb7ec1f", null ]
    ] ],
    [ "could_open_probability", "group__libopenmpt__cpp.html#ga95fd9b6781cd291b48a1c3e12a3c85e1", null ],
    [ "could_open_propability", "group__libopenmpt__cpp.html#gaad5e4ff0e24869d7a9808ac4262283f2", null ],
    [ "get_core_version", "group__libopenmpt__cpp.html#gac37146367d4849a17a297d388cfb4811", null ],
    [ "get_library_version", "group__libopenmpt__cpp.html#gaeece2f6ce1045a5f519c93ce19e6eef3", null ],
    [ "get_supported_extensions", "group__libopenmpt__cpp.html#gaaa2081245974442462d76e8b9bc9380a", null ],
    [ "is_extension_supported", "group__libopenmpt__cpp.html#ga499346669636c80f8df0d65145d3fed0", null ],
    [ "is_extension_supported2", "group__libopenmpt__cpp.html#ga2377657c477285d9e47462247a755bc7", null ],
    [ "probe_file_header", "group__libopenmpt__cpp.html#gaa3b9b7a7d0d3d791c8154bf330d96b01", null ],
    [ "probe_file_header", "group__libopenmpt__cpp.html#gaeb1b17a8535ac1407999a849340d7ef6", null ],
    [ "probe_file_header", "group__libopenmpt__cpp.html#ga77facf516dd9b626847f91ac26047336", null ],
    [ "probe_file_header", "group__libopenmpt__cpp.html#gad77e7cf2361d664fda8ae8461c1dc7a0", null ],
    [ "probe_file_header", "group__libopenmpt__cpp.html#ga6412e44030e40ca67aaa187691ad8e9c", null ],
    [ "probe_file_header_get_recommended_size", "group__libopenmpt__cpp.html#gaf70a8d33fdceca5a821755106e840dcb", null ],
    [ "LIBOPENMPT_ATTR_DEPRECATED", "group__libopenmpt__cpp.html#ga80db80ac87f76b79e2a924f62041d1e4", null ]
];
